@@ -1,5 +1,5 @@
 /* libwmf ("player.h"): library for wmf conversion
-   Copyright (C) 2000 - various; see CREDITS, ChangeLog, and sources
+   Copyright (C) 2000,2001 - various; see CREDITS, ChangeLog, and sources
 
    The libwmf Library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License as
@@ -115,7 +115,7 @@ static void D_Rect (wmfAPI*,wmfD_Rect*,U16,U16,U16,U16);
 
 static void D_Coord_Register (wmfAPI*,wmfD_Coord,float);
 
-static void SetMapMode (wmfAPI*,U16 map_mode);
+static void WmfSetMapMode (wmfAPI*,U16 map_mode);
 
 static double PixelWidth (wmfAPI*);
 static double PixelHeight (wmfAPI*);
@@ -146,8 +146,8 @@ static void REGION_SubtractNonO1 (wmfAPI*,wmfRegion*,wmfD_Rect*,wmfD_Rect*,float
 static void REGION_IntersectRegion (wmfAPI*,wmfRegion*,wmfRegion*,wmfRegion*);
 static void REGION_IntersectO (wmfAPI*,wmfRegion*,wmfD_Rect*,wmfD_Rect*,wmfD_Rect*,wmfD_Rect*,float,float);
 
-static void SetRectRgn (wmfAPI*,wmfRegion*,wmfD_Rect*);
-static void CombineRgn (wmfAPI*,wmfRegion*,wmfRegion*,wmfRegion*,U16);
+static void WmfSetRectRgn (wmfAPI*,wmfRegion*,wmfD_Rect*);
+static void WmfCombineRgn (wmfAPI*,wmfRegion*,wmfRegion*,wmfRegion*,U16);
 
 static void rect_merge (wmfAPI*,wmfRegion*,wmfD_Rect*,float,float);
 
@@ -169,53 +169,57 @@ static U16 ParU16 (wmfAPI*,wmfRecord*,unsigned long);
 static S16 ParS16 (wmfAPI*,wmfRecord*,unsigned long);
 static S32 ParS32 (wmfAPI*,wmfRecord*,unsigned long);
 
+static int PutParU16 (wmfAPI*,wmfRecord*,unsigned long,U16);
+
 static wmfRecord OffsetRecord (wmfAPI*,wmfRecord*,unsigned long);
 
 /* In: meta.h
  */
 
-static void meta_mapmode (wmfAPI*,wmfRecord*);
-static void meta_orgext (wmfAPI*,wmfRecord*);
-static void meta_scale (wmfAPI*,wmfRecord*);
-static void meta_moveto (wmfAPI*,wmfRecord*);
-static void meta_flood (wmfAPI*,wmfRecord*);
-static void meta_pixel (wmfAPI*,wmfRecord*);
-static void meta_arc (wmfAPI*,wmfRecord*);
-static void meta_ellipse (wmfAPI*,wmfRecord*);
-static void meta_line (wmfAPI*,wmfRecord*);
-static void meta_lines (wmfAPI*,wmfRecord*);
-static void meta_polygon (wmfAPI*,wmfRecord*);
-static void meta_polygons (wmfAPI*,wmfRecord*);
-static void meta_round (wmfAPI*,wmfRecord*);
-static void meta_rect (wmfAPI*,wmfRecord*);
-static void meta_rgn_brush (wmfAPI*,wmfRecord*);
-static void meta_rgn_paint (wmfAPI*,wmfRecord*);
-static void meta_rgn_create (wmfAPI*,wmfRecord*);
-static void meta_clip_select (wmfAPI*,wmfRecord*);
-static void meta_clip_offset (wmfAPI*,wmfRecord*);
-static void meta_clip_combine (wmfAPI*,wmfRecord*);
-static void meta_dib_draw (wmfAPI*,wmfRecord*);
-static void meta_dib_brush (wmfAPI*,wmfRecord*);
-static void meta_rop_draw (wmfAPI*,wmfRecord*);
-static void meta_dc_set (wmfAPI*,wmfRecord*);
-static void meta_dc_color (wmfAPI*,wmfRecord*);
-static void meta_dc_select (wmfAPI*,wmfRecord*);
-static void meta_dc_save (wmfAPI*,wmfRecord*);
-static void meta_dc_restore (wmfAPI*,wmfRecord*);
-static void meta_text (wmfAPI*,wmfRecord*);
-static void meta_pen_create (wmfAPI*,wmfRecord*);
-static void meta_brush_create (wmfAPI*,wmfRecord*);
-static void meta_font_create (wmfAPI*,wmfRecord*);
-static void meta_palette_create (wmfAPI*,wmfRecord*);
-static void meta_delete (wmfAPI*,wmfRecord*);
-static void meta_unused (wmfAPI*,wmfRecord*);
+static int meta_mapmode (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_orgext (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_scale (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_moveto (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_flood (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_pixel (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_arc (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_ellipse (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_line (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_lines (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_polygon (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_polygons (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_round (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_rect (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_rgn_brush (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_rgn_paint (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_rgn_create (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_clip_select (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_clip_offset (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_clip_combine (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_dib_draw (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_dib_brush (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_rop_draw (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_dc_set (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_dc_color (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_dc_select (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_dc_save (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_dc_restore (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_text (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_pen_create (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_brush_create (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_font_create (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_palette_create (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_delete (wmfAPI*,wmfRecord*,wmfAttributes*);
+static int meta_unused (wmfAPI*,wmfRecord*,wmfAttributes*);
+
+static void polypoly_construct (wmfAPI*,wmfPolyPoly_t*,wmfPolyLine_t*,U16);
 
 static void diagnose_object (wmfAPI*,unsigned int,wmfObject*);
 
 /* In: player.c
  */
 
-static wmf_error_t PlayMetaFile (wmfAPI*);
+static wmf_error_t WmfPlayMetaFile (wmfAPI*);
 
 static U16 ParU16 (wmfAPI*,wmfRecord*,unsigned long);
 static S16 ParS16 (wmfAPI*,wmfRecord*,unsigned long);
@@ -247,7 +251,7 @@ static wmfRecord OffsetRecord (wmfAPI*,wmfRecord*,unsigned long);
 
 #define SCAN_DIAGNOSTIC(API,MESG) if (SCAN ((API)) && DIAG ((API))) fputs (MESG,stderr);
 
-/* Modes for SetMapMode
+/* Modes for WmfSetMapMode
  */
 #define MM_TEXT        1
 #define MM_LOMETRIC    2
